@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 require XSLoader;
 XSLoader::load('Class::XSAccessor', $VERSION);
@@ -78,21 +78,13 @@ sub _generate_accessor {
     newxs_getter($subname, $hashkey);
   }
   elsif ($type eq 'setter') {
-    if ($chained) {
-      newxs_chained_setter($subname, $hashkey);
-    } else {
-      newxs_setter($subname, $hashkey);
-    }
+    newxs_setter($subname, $hashkey, $chained);
   }
   elsif ($type eq 'predicate') {
     newxs_predicate($subname, $hashkey);
   }
   else {
-    if ($chained) {
-      newxs_chained_accessor($subname, $hashkey);
-    } else {
-      newxs_accessor($subname, $hashkey);
-    }
+    newxs_accessor($subname, $hashkey, $chained);
   }
 }
 
